==> io-8.x-1.1.tar.gz: io/js/io.pager.js <==
/**
 * @file
 * Provides AJAX append command for both automatic or manual pagers.
 */

(function ($, Drupal, drupalSettings, _db, window, document) {

  'use strict';

  drupalSettings.io = drupalSettings.io || {};
  Drupal.blazy = Drupal.blazy || {};

  var _pagerAutoload = '.pager--io--autoload';
  var _oncePager = 'io-pager';
  var _viewsAjax = Drupal.views.ajaxView || {};
  var _viewsProto = _viewsAjax.prototype || {};
  var _viewsAttach = _viewsProto.attachPagerLinkAjax;

  // Provides the IO append command.
  Drupal.AjaxCommands.prototype.ioAppend = function (ajax, response) {
    // Configured options for the pager.
    var opts = response.settings;
    var view = Drupal.views.instances['views_dom_id:' + opts.view_dom_id];
    var settings = ajax.settings || drupalSettings;
    var $newContentWrap = $('<div/>').html($.trim(response.data));
    var $newContent = $newContentWrap.contents();
    var $wrapper = typeof view === 'undefined' ? $('.js-view-dom-id-' + opts.view_dom_id) : view.$view;

    // If removing content from the wrapper, detach behaviors first.
    Drupal.detachBehaviors($wrapper[0], settings);

    // Update the pager.
    var $existingPager = $wrapper.find(opts.pagerSelector);
    $existingPager.html($newContent.find(opts.pagerSelector).children());

    // Add the new content to the page.
    $wrapper.find(opts.contentSelector)[opts.method]($newContent.find(opts.contentSelector).children());

    // Remove once so that the exposed form and pager are processed on attach.
    $wrapper.removeOnce('ajax-pager');
    $existingPager.removeOnce(_oncePager);
    if (typeof view !== 'undefined') {
      view.$exposed_form.removeOnce('exposed-form');
    }

    // Attach all JavaScript behaviors to the newly loaded content.
    Drupal.attachBehaviors($wrapper[0], settings);
  };

  /**
   * Intersection Observer API public methods for Views pagers.
   *
   * @namespace
   */
  Drupal.io.pager = _db.extend({}, Drupal.io.base, {
    settings: drupalSettings.io.pager || {},
    dataHit: 'data-io-pager-hit',
    dataTrigger: 'data-io-pager-trigger',
    dataLoaded: 'data-io-pager-loaded',
    trigger: '[data-io-pager-trigger]',
    $trigger: null,
    globals: function () {
      var me = this;
      var commons = {
        intersecting: me.intersecting.bind(me),
        success: me.success.bind(me),
        error: me.error.bind(me)
      };

      return _db.extend({}, me.settings, commons);
    },

    intersecting: function (el) {
      var me = this;

      // Bail out if AJAX is already requested, or successful.
      if (me.isError(el) || !el.hasAttribute(me.dataHit)) {
        el.click();

        el.setAttribute(me.dataHit, 0);
      }
    }
  });

  // Overrides Drupal.views.ajaxView.attachPagerLinkAjax().
  _viewsProto.attachPagerLinkAjax = function (id, link) {
    var _me = this;

    // Makes the _super run first so that its data available.
    _viewsAttach.apply(_me, arguments);

    // Overrides this.pagerAjax = Drupal.ajax(selfSettings).
    var _pagerAjax = _me.pagerAjax;
    var _ajaxOptions = _pagerAjax.options;
    var _complete = _ajaxOptions.complete;

    // Overrides Drupal.Ajax.options.complete.
    _ajaxOptions.complete = function complete(xmlhttprequest, status) {
      if (link.hasAttribute('data-io-pager-trigger')) {
        // @todo recheck var el = _pagerAjax.element;
        var parent = _db.closest(link, _pagerAutoload);

        Drupal.io.pager.$trigger = link;

        // Prevents dead errors without resolutions.
        var error = status === 'error' || status === 'parsererror';
        Drupal.io.pager[error ? 'error' : 'success'](link, error ? -1 : 1, parent);
      }

      return _complete.apply(_me, arguments);
    };
  };

  /**
   * IO automatic pager utility functions.
   *
   * @param {int} i
   *   The index of the current element.
   * @param {HTMLElement} elm
   *   The IO pager HTML element.
   */
  function doPager(i, elm) {
    var me = Drupal.io.pager;
    var block = Drupal.io.block || {};
    var link = elm.querySelector(me.trigger);

    // Initializes Ajaxin instance, if available.
    me.ajaxin = me.initAjaxin(me.settings);

    // Initializes Io pager instance.
    me.init = me.run(me.globals());

    // The IO pager is all done if no link is found.
    if (link === null) {
      elm.setAttribute(me.dataLoaded, 1);

      // When the pager is done, IO is likely disconnected causing blocks fail.
      // Helps the IO block observer to reinit if exists on the same page.
      if (me.isIo() && block && block.init !== null) {
        block.init.reinit();
      }
    }
  }

  /**
   * Auloload ajaxified views using the IO API, or the old scroll event, bLazy.
   *
   * @type {Drupal~behavior}
   */
  Drupal.behaviors.ioPager = {
    attach: function (context) {
      $(context).find(_pagerAutoload).once(_oncePager).each(doPager);
    },
    detach: function (context, settings, trigger) {
      if (trigger === 'unload') {
        $(context).find(_pagerAutoload).removeOnce(_oncePager);
      }
    }
  };

})(jQuery, Drupal, drupalSettings, dBlazy, this, this.document);

==> io-8.x-1.2.tar.gz: io/js/io.pager.js <==
/**
 * @file
 * Provides AJAX append command for both automatic or manual pagers.
 */

(function ($, Drupal, drupalSettings, _db, window, document) {

  'use strict';

  drupalSettings.io = drupalSettings.io || {};
  Drupal.blazy = Drupal.blazy || {};

  var _pagerAutoload = '.pager--io--autoload';
  var _oncePager = 'io-pager';
  var _viewsAjax = Drupal.views.ajaxView || {};
  var _viewsProto = _viewsAjax.prototype || {};
  var _viewsAttach = _viewsProto.attachPagerLinkAjax;

  // Provides the IO append command.
  Drupal.AjaxCommands.prototype.ioAppend = function (ajax, response) {
    // Configured options for the pager.
    var opts = response.settings || {};
    var contentSelector = opts.contentSelector || (opts.style === 'table' ? '.views-table tbody' : '[data-io-pager]');
    var method = opts.method || 'append';
    var pagerSelector = opts.pagerSelector || '.pager--io';
    var view_dom_id = opts.view_dom_id;
    var view = Drupal.views.instances['views_dom_id:' + view_dom_id];
    var settings = ajax.settings || drupalSettings;
    var $newContentWrap = $('<div/>').html($.trim(response.data));
    var $newContent = $newContentWrap.contents();
    var $wrapper = typeof view === 'undefined' ? $('.js-view-dom-id-' + view_dom_id) : view.$view;

    // If removing content from the wrapper, detach behaviors first.
    Drupal.detachBehaviors($wrapper[0], settings);

    // Update the pager.
    var $existingPager = $wrapper.find(pagerSelector);
    $existingPager.html($newContent.find(pagerSelector).children());

    // Add the new content to the page.
    $wrapper.find(contentSelector)[method]($newContent.find(contentSelector).children());

    // Remove once so that the exposed form and pager are processed on attach.
    $wrapper.removeOnce('ajax-pager');
    $existingPager.removeOnce(_oncePager);
    if (typeof view !== 'undefined') {
      view.$exposed_form.removeOnce('exposed-form');
    }

    // Attach all JavaScript behaviors to the newly loaded content.
    Drupal.attachBehaviors($wrapper[0], settings);
  };

  /**
   * Intersection Observer API public methods for Views pagers.
   *
   * @namespace
   */
  Drupal.io.pager = _db.extend({}, Drupal.io.base, {
    settings: drupalSettings.io.pager || {},
    dataHit: 'data-io-pager-hit',
    dataTrigger: 'data-io-pager-trigger',
    dataLoaded: 'data-io-pager-loaded',
    trigger: '[data-io-pager-trigger]',
    $trigger: null,
    globals: function () {
      var me = this;
      var commons = {
        intersecting: me.intersecting.bind(me),
        success: me.success.bind(me),
        error: me.error.bind(me)
      };

      return _db.extend({}, me.settings, commons);
    },

    loadStatic: function (el, path) {
      var $view = $(el).closest('[data-io-view]');
      var matches = /(js-view-dom-id-\w+)/.exec($view.attr('class'));
      var domId = matches[1].replace('js-view-dom-id-', '');
      var style = $view.attr('data-io-view');

      // @todo use Drupal.Ajax like io.block.js::ajax.
      // var ajax = new Drupal.Ajax(null, null, _settings);
      $.ajax({
        url: path,
        success: function (data) {
          var $data = $(data);
          var $newView = $('[data-io-view]:first', $data);
          var classes = $view.attr('class');

          if ($newView.length) {
            var response = {
              command: 'ioAppend',
              data: $newView.attr('class', classes)[0].outerHTML,
              io: 'pager',
              settings: {
                view_dom_id: domId,
                style: style
              }
            };
            Drupal.AjaxCommands.prototype.ioAppend({}, response);
          }
        },
        dataType: 'html'
      });
    },

    loadOrClick: function (el) {
      var me = this;
      var path = el.href;

      if (path.indexOf('/page/') >= 0) {
        me.loadStatic(el, path);
      }
      else {
        el.click();
      }
    },

    intersecting: function (el) {
      var me = this;

      // Bail out if AJAX is already requested, or successful.
      if (me.isError(el) || !el.hasAttribute(me.dataHit)) {
        me.loadOrClick(el);

        el.setAttribute(me.dataHit, 0);
      }
    }
  });

  // Overrides Drupal.views.ajaxView.attachPagerLinkAjax().
  _viewsProto.attachPagerLinkAjax = function (id, link) {
    var _me = this;

    // Makes the _super run first so that its data available.
    _viewsAttach.apply(_me, arguments);

    // Overrides this.pagerAjax = Drupal.ajax(selfSettings).
    var _pagerAjax = _me.pagerAjax;
    var _ajaxOptions = _pagerAjax.options;
    var _complete = _ajaxOptions.complete;

    // Overrides Drupal.Ajax.options.complete.
    _ajaxOptions.complete = function complete(xmlhttprequest, status) {
      if (link.hasAttribute('data-io-pager-trigger')) {
        // @todo recheck var el = _pagerAjax.element;
        var parent = _db.closest(link, _pagerAutoload);

        Drupal.io.pager.$trigger = link;

        // Prevents dead errors without resolutions.
        var error = status === 'error' || status === 'parsererror';
        Drupal.io.pager[error ? 'error' : 'success'](link, error ? -1 : 1, parent);
      }

      return _complete.apply(_me, arguments);
    };
  };

  /**
   * IO automatic pager utility functions.
   *
   * @param {int} i
   *   The index of the current element.
   * @param {HTMLElement} elm
   *   The IO pager HTML element.
   */
  function doPager(i, elm) {
    var me = Drupal.io.pager;
    var block = Drupal.io.block || {};
    var link = elm.querySelector(me.trigger);

    // Initializes Ajaxin instance, if available.
    me.ajaxin = me.initAjaxin(me.settings);

    // Initializes Io pager instance.
    me.init = me.run(me.globals());

    // The IO pager is all done if no link is found.
    if (link === null) {
      elm.setAttribute(me.dataLoaded, 1);

      // When the pager is done, IO is likely disconnected causing blocks fail.
      // Helps the IO block observer to reinit if exists on the same page.
      if (me.isIo() && block && block.init !== null) {
        block.init.reinit();
      }
    }
  }

  /**
   * Auloload ajaxified views using the IO API, or the old scroll event, bLazy.
   *
   * @type {Drupal~behavior}
   */
  Drupal.behaviors.ioPager = {
    attach: function (context) {
      $(context).find(_pagerAutoload).once(_oncePager).each(doPager);
    },
    detach: function (context, settings, trigger) {
      if (trigger === 'unload') {
        $(context).find(_pagerAutoload).removeOnce(_oncePager);
      }
    }
  };

})(jQuery, Drupal, drupalSettings, dBlazy, this, this.document);
